/*
 * Copyright 2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.commandline;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Arrays;
import java.util.List;

import org.junit.Test;

import com.springsource.bundlor.commandline.internal.Configuration;

public class BundlorTests {

    private final StubBundlor bundlor = new StubBundlor();

    @Test
    public void executeDontFailOnWarnings() {
        this.bundlor.run(new String[] { "-i", "test" });
        assertTrue(this.bundlor.getStubBundlorExecutor().getCalled());
    }

    @Test
    public void executeFailOnWarnings() {
        this.bundlor.run(new String[] { "-i", "test", "-f" });
        assertTrue(this.bundlor.getStubBundlorExecutor().getCalled());
        assertEquals(-1, this.bundlor.getCode());
    }

    private static class StubBundlor extends Bundlor {

        private static final StubBundlorExecutor executor = new StubBundlorExecutor();

        private volatile int code;

        @Override
        protected BundlorExecutor getBundlorExecutor(Configuration configuration) {
            return executor;
        }

        @Override
        protected void exit(int code) {
            this.code = code;
        }

        public int getCode() {
            return code;
        }

        public StubBundlorExecutor getStubBundlorExecutor() {
            return executor;
        }

    }

    private static class StubBundlorExecutor implements BundlorExecutor {

        private volatile boolean called = false;

        public List<String> execute() {
            this.called = true;
            return Arrays.asList("warning");
        }

        public boolean getCalled() {
            return this.called;
        }
    }
}
